#######################################################
##### R SCRIPT FOR RUNNING THE METACOMMUNITY MODEL ####
#######################################################

##### NIMBLE code for running running the Bayesian Markov Chain Monte Carlo regularised logistic metacommunity model described in the manuscript.   

fish.model<- nimbleCode({
    

    ### Define the priors for the species-specific intercepts using a Multivariate Normal Distribution
    ### n.species: number of fishes (14 pre-1970 and 32 post-1970)

	alpha.sps[1:n.species]~dmnorm(mean=alphasps.mean[1:n.species], prec=tau.sps[1:n.species, 1:n.species])

	for (j in 1:n.species){
	alphasps.mean[j]<-0

	}

    ### Define the precision matrix in the MVN distribution using a Wishart prior
	tau.sps[1:n.species, 1:n.species]~dwish(S=S3.sps[1:n.species, 1:n.species], df=df1)

    df1<-n.species+1

	
	### Define the priors for the drainage-specific intercepts using a Multivariate Normal Distribution
    ### n.drainage: number of drainages (144)

	alpha.dr[1:n.drainage]~dmnorm(mean=alphadr.mean[1:n.drainage], prec=tau.ct[1:n.drainage, 1:n.drainage])

	for (j in 1:n.drainage){
	alphadr.mean[j]<-0

	}

    ### Define the precision matrix in the MVN distribution using a Wishart prior

	tau.dr[1:n.drainage, 1:n.drainage]~dwish(S=S3.drainage[1:n.drainage, 1:n.drainage], df=df2)

    df2<-n.drainage+1

	### Prior distribution for the slopes of the model; n.covs: number of covariates (12 in our models)

	for (j in 1:n.covs){
		beta[j]~dnorm(0, sd=3)
	}

 ### Likelihood for the complete regularised logistic metacommunity model
 ### Sample size: number of species by drainage combinations (pre-1970: 2016; post-1970: 4608)

	for (i in 1:sample.size){

        ### Logistic regression including species and drainage-specific intercepts, and 12 covariates

		logit(p[i])<-alpha.sps[species[i]]+alpha.dr[drainage[i]]+beta[1]*area[i]+beta[2]*HFI[i]+beta[3]*flength[i]+beta[4]*facc[i]+beta[5]*up.slope[i]+beta[6]*up.elev[i]+
		beta[7]*min.temp[i]+beta[8]*max.temp[i]+beta[9]*size[i]+beta[10]*trophic[i]+beta[11]*resilience[i]+beta[12]*fecundity[i]

        ### Use a Bernoulli distribution to model the establishment of each alien fish species in each drainage
		established[i]~dbern(p[i])

	}

})
